@@ -25,7 +25,7 @@ class Parser(bs4.BeautifulSoup, ABC):
         Returns:
 
         """
-        util.save_to_file(self, self.url)
+        util.save_to_file(self.encode(), self.url)
 
     def generate_filename(self):
         return util.filename_from_url(self.url)
